// Don't modify, generated using unocommands.py

var unoCommandsArray = {
	AcceptAllTrackedChanges:{text:{menu:_('Accept All'),},},
	AcceptTrackedChanges:{text:{menu:_('~Manage...'),},},
	AnchorMenu:{global:{menu:_('Anc~hor'),},},
	ArrangeFrameMenu:{text:{menu:_('Arrange'),},},
	ArrangeMenu:{global:{menu:_('A~rrange'),},presentation:{menu:_('~Arrange'),},},
	AutoFormatMenu:{text:{menu:_('AutoCorr~ect'),},},
	BackgroundColor:{global:{menu:_('Background Color'),},},
	Bold:{global:{menu:_('Bold'),},},
	BringToFront:{global:{menu:_('~Bring to Front'),},},
	CenterPara:{global:{context:_('Align Center'),menu:_('Center'),},},
	ChangeCaseRotateCase:{global:{menu:_('Cycle Case'),},},
	ChangeCaseToLower:{global:{menu:_('~lowercase'),},},
	ChangeCaseToSentenceCase:{global:{menu:_('~Sentence case'),},},
	ChangeCaseToTitleCase:{global:{menu:_('~Capitalize Every Word'),},},
	ChangeCaseToToggleCase:{global:{menu:_('~tOGGLE cASE'),},},
	ChangeCaseToUpper:{global:{menu:_('~UPPERCASE'),},},
	ChangesMenu:{global:{menu:_('Track Chan~ges'),},},
	ClearOutline:{global:{menu:_('~Remove Outline'),},},
	CommonAlignBottom:{global:{menu:_('Bottom'),},},
	CommonAlignHorizontalCenter:{global:{menu:_('Centered'),},},
	CommonAlignJustified:{global:{menu:_('Justified'),},},
	CommonAlignLeft:{global:{menu:_('Left'),},},
	CommonAlignRight:{global:{menu:_('Right'),},},
	CommonAlignTop:{global:{menu:_('Top'),},},
	CommonAlignVerticalCenter:{global:{menu:_('Center'),},},
	ConditionalFormatMenu:{spreadsheet:{menu:_('C~onditional'),},},
	ContinueNumbering:{text:{menu:_('Continue previous numbering'),},},
	ControlCodes:{text:{menu:_('For~matting Marks'),},},
	Copy:{global:{menu:_('Cop~y'),},},
	CopyHyperlinkLocation:{text:{menu:_('Copy Hyperlink Location'),},},
	Cut:{global:{menu:_('~Cut'),},},
	DataFilterAutoFilter:{spreadsheet:{menu:_('Auto~Filter'),},},
	DataFilterHideAutoFilter:{spreadsheet:{menu:_('~Hide AutoFilter'),},},
	DataFilterRemoveFilter:{spreadsheet:{menu:_('~Reset Filter'),},},
	DataFilterSpecialFilter:{spreadsheet:{menu:_('~Advanced Filter...'),},},
	DataFilterStandardFilter:{spreadsheet:{menu:_('~Standard Filter...'),},},
	DataMenu:{global:{menu:_('~Data'),},},
	DataSort:{spreadsheet:{menu:_('~Sort...'),},},
	DecrementIndent:{global:{context:_('Decrease Indent'),menu:_('Decrease Indent'),},},
	DecrementLevel:{text:{menu:_('Demote One Level'),},},
	DecrementSubLevels:{text:{menu:_('Demote One Level With Subpoints'),},},
	DefaultBullet:{global:{context:_('Toggle Bulleted List'),menu:_('~Bulleted List'),},},
	DefaultNumbering:{global:{context:_('Toggle Numbered List'),menu:_('~Numbered List'),},},
	DelBreakMenu:{spreadsheet:{menu:_('Delete Page ~Break'),},},
	DeleteAllNotes:{global:{menu:_('Delete All Comments'),},spreadsheet:{menu:_('Delete All Comments'),},},
	DeleteAuthor:{global:{menu:_('Delete All Comments by This Author'),},},
	DeleteColumnbreak:{spreadsheet:{menu:_('~Column Break'),},},
	DeleteColumns:{presentation:{menu:_('Delete Column'),},spreadsheet:{menu:_('Delete Columns'),},text:{menu:_('~Columns'),},},
	DeleteComment:{global:{menu:_('Delete Comment'),},},
	DeleteRowbreak:{spreadsheet:{menu:_('~Row Break'),},},
	DeleteRows:{presentation:{menu:_('Delete Row'),},spreadsheet:{menu:_('Delete Rows'),},text:{menu:_('~Rows'),},},
	DeleteSlide:{presentation:{menu:_('~Delete Slide'),},},
	DeleteTable:{text:{menu:_('~Table'),},},
	DownSearch:{global:{menu:_('Find Next'),},},
	DuplicateSlide:{presentation:{menu:_('Duplicate ~Slide'),},},
	EditMenu:{global:{menu:_('~Edit'),},},
	EditStyle:{global:{menu:_('~Edit Style...'),},presentation:{menu:_('E~dit Style...'),},},
	EntireCell:{text:{menu:_('C~ell'),},},
	EntireColumn:{presentation:{menu:_('Select Column'),},text:{menu:_('~Column'),},},
	EntireRow:{presentation:{menu:_('Select Row'),},text:{menu:_('~Row'),},},
	FilterMenu:{spreadsheet:{menu:_('More ~Filters'),},},
	FontColor:{global:{menu:_('Font Color'),},text:{menu:_('Font Color'),},},
	FontDialog:{global:{menu:_('C~haracter...'),},},
	FormatArea:{global:{menu:_('A~rea...'),},},
	FormatBulletsMenu:{global:{menu:_('Lis~ts'),},},
	FormatCellDialog:{spreadsheet:{context:_('~Format Cells...'),menu:_('Ce~lls...'),},},
	FormatColumns:{text:{menu:_('Co~lumns...'),},},
	FormatLine:{global:{menu:_('L~ine...'),},},
	FormatMenu:{global:{menu:_('F~ormat'),},},
	FormatObjectMenu:{global:{menu:_('~Object and Shape'),},text:{menu:_('Text Box and Shap~e'),},},
	FormatSpacingMenu:{global:{menu:_('~Spacing'),},},
	FormatTextMenu:{global:{menu:_('Te~xt'),},},
	FormattingMarkMenu:{global:{menu:_('Formatting Mark'),},},
	FullScreen:{global:{menu:_('F~ull Screen'),},},
	Group:{global:{menu:_('~Group...'),},},
	GroupOutlineMenu:{spreadsheet:{menu:_('~Group and Outline'),},},
	Grow:{global:{menu:_('Increase Size'),},},
	HelpMenu:{global:{menu:_('~Help'),},},
	Hide:{spreadsheet:{menu:_('~Hide Sheet'),},},
	HideColumn:{spreadsheet:{context:_('H~ide Columns'),menu:_('~Hide'),},},
	HideDetail:{global:{menu:_('~Hide Details'),},},
	HideRow:{spreadsheet:{context:_('H~ide Rows'),menu:_('H~ide'),},},
	HyperlinkDialog:{global:{menu:_('~Hyperlink...'),},},
	IncrementIndent:{global:{context:_('Increase Indent'),menu:_('Increase Indent'),},},
	IncrementLevel:{text:{menu:_('Promote One Level'),},},
	IncrementSubLevels:{text:{menu:_('Promote One Level With Subpoints'),},},
	InsertAnnotation:{global:{context:_('Insert Comment'),menu:_('Comme~nt'),},presentation:{menu:_('Comme~nt'),},spreadsheet:{context:_('Insert Co~mment'),menu:_('Comm~ent'),},},
	InsertAuthorField:{presentation:{menu:_('~Author'),},text:{menu:_('First ~Author'),},},
	InsertBreakMenu:{spreadsheet:{menu:_('Insert Page ~Break'),},},
	InsertColumnBreak:{spreadsheet:{menu:_('~Column Break'),},text:{menu:_('Insert Column Break'),},},
	InsertColumnsAfter:{presentation:{menu:_('Insert Column After'),},spreadsheet:{context:_('Insert Columns ~After'),menu:_('Columns ~After'),},text:{menu:_('Columns ~After'),},},
	InsertColumnsBefore:{presentation:{menu:_('Insert Column Before'),},spreadsheet:{context:_('Insert Columns ~Before'),menu:_('Columns ~Before'),},text:{menu:_('Columns ~Before'),},},
	InsertColumnsMenu:{spreadsheet:{menu:_('Insert Co~lumns'),},},
	InsertDateField:{text:{menu:_('~Date'),},},
	InsertEndnote:{text:{menu:_('~Endnote'),},},
	InsertField:{text:{menu:_('~More Fields...'),},},
	InsertFootnote:{text:{context:_('Insert Footnote'),menu:_('~Footnote'),},},
	InsertGraphic:{global:{context:_('Insert Image...'),menu:_('~Image...'),},},
	InsertHardHyphen:{global:{menu:_('Non-br~eaking hyphen'),},},
	InsertHeaderFooterMenu:{text:{menu:_('He~ader and Footer'),},},
	InsertIndexesEntry:{text:{menu:_('~Index Entry...'),},},
	InsertLRM:{global:{menu:_('~Left-to-right mark'),},},
	InsertMenu:{global:{menu:_('~Insert'),},},
	InsertNeutralParagraph:{text:{menu:_('Insert Unnumbered Entry'),},},
	InsertNonBreakingSpace:{global:{menu:_('~Non-breaking space'),},},
	InsertObjectChart:{global:{context:_('Insert Chart'),menu:_('~Chart...'),},},
	InsertPageCountField:{text:{menu:_('Page ~Count'),},},
	InsertPageFooter:{text:{menu:_('Foote~r'),},},
	InsertPageHeader:{text:{menu:_('He~ader'),},},
	InsertPageNumberField:{global:{menu:_('~Page Numbers...'),},text:{menu:_('~Page Number'),},},
	InsertPagebreak:{text:{menu:_('~Page Break'),},},
	InsertRLM:{global:{menu:_('~Right-to-left mark'),},},
	InsertRowBreak:{spreadsheet:{menu:_('~Row Break'),},},
	InsertRowsAfter:{presentation:{menu:_('Insert Row Below'),},spreadsheet:{context:_('Insert Rows ~Below'),menu:_('Rows ~Below'),},text:{menu:_('Rows ~Below'),},},
	InsertRowsBefore:{presentation:{menu:_('Insert Row Above'),},spreadsheet:{context:_('Insert Rows ~Above'),menu:_('Rows ~Above'),},text:{menu:_('Rows ~Above'),},},
	InsertRowsMenu:{spreadsheet:{menu:_('Insert ~Rows'),},},
	InsertSlide:{presentation:{menu:_('~New Slide'),},},
	InsertSoftHyphen:{global:{menu:_('S~oft hyphen'),},},
	InsertSymbol:{global:{context:_('Insert Special Character'),menu:_('S~pecial Character...'),},},
	InsertTimeField:{global:{menu:_('Time Field'),},text:{menu:_('~Time'),},},
	InsertTitleField:{text:{menu:_('T~itle'),},},
	InsertTopicField:{text:{menu:_('~Subject'),},},
	InsertZWNBSP:{global:{menu:_('No-width no ~break'),},},
	InsertZWSP:{global:{menu:_('No-~width optional break'),},},
	Italic:{global:{menu:_('Italic'),},},
	JumpDownThisLevel:{text:{menu:_('To Next Paragraph in Level'),},},
	JumpUpThisLevel:{text:{menu:_('To Previous Paragraph in Level'),},},
	JustifyPara:{global:{menu:_('Justified'),},},
	LanguageMenu:{global:{menu:_('Language'),},},
	LayoutStatus:{presentation:{menu:_('Layout'),},},
	LeftPara:{global:{context:_('Align Left'),menu:_('Left'),},},
	MergeCells:{presentation:{menu:_('Merge Cells'),},spreadsheet:{menu:_('Merge Cells'),},text:{menu:_('Merge Cells'),},},
	MoveDown:{text:{menu:_('Move Down'),},},
	MoveDownSubItems:{text:{menu:_('Move Down with Subpoints'),},},
	MoveUp:{text:{menu:_('Move Up'),},},
	MoveUpSubItems:{text:{menu:_('Move Up with Subpoints'),},},
	NextTrackedChange:{text:{menu:_('Next'),},},
	NumberFormatCurrency:{spreadsheet:{context:_('Format as Currency'),menu:_('Currency'),},text:{menu:_('Number Format: Currency'),},},
	NumberFormatDate:{spreadsheet:{context:_('Format as Date'),menu:_('Date'),},text:{menu:_('Number Format: Date'),},},
	NumberFormatDecDecimals:{spreadsheet:{menu:_('Delete Decimal Place'),},},
	NumberFormatDecimal:{spreadsheet:{context:_('Format as Number'),menu:_('Number'),},text:{menu:_('Number Format: Decimal'),},},
	NumberFormatIncDecimals:{spreadsheet:{menu:_('Add Decimal Place'),},},
	NumberFormatPercent:{spreadsheet:{context:_('Format as Percent'),menu:_('Percent'),},text:{menu:_('Number Format: Percent'),},},
	NumberingStart:{text:{menu:_('Restart Numbering'),},},
	ObjectBackOne:{global:{menu:_('Back One'),},},
	ObjectForwardOne:{global:{menu:_('Forward One'),},},
	OnlineAutoFormat:{text:{menu:_('~While Typing'),},},
	OpenHyperlinkOnCursor:{global:{menu:_('Open Hyperlink'),},},
	OutlineBullet:{global:{menu:_('~Bullets and Numbering...'),},},
	OutlineFont:{global:{menu:_('Outline'),},},
	Overline:{global:{menu:_('Overline'),},},
	PageDialog:{global:{menu:_('~Page...'),},text:{menu:_('~Page...'),},},
	PageDown:{text:{menu:_('Next Page'),},},
	PageUp:{text:{menu:_('Previous Page'),},},
	ParaLeftToRight:{global:{menu:_('Left-To-Right'),},},
	ParaRightToLeft:{global:{menu:_('Right-To-Left'),},},
	ParagraphDialog:{global:{menu:_('P~aragraph...'),},},
	ParaspaceDecrease:{global:{menu:_('Decrease Paragraph Spacing'),},},
	ParaspaceIncrease:{global:{menu:_('Increase Paragraph Spacing'),},},
	Paste:{global:{menu:_('~Paste'),},},
	PasteSpecialMenu:{global:{menu:_('Paste ~Special'),},},
	PasteUnformatted:{global:{context:_('~Unformatted Text'),menu:_('Paste Unformatted Text'),},},
	PickList:{global:{menu:_('~File'),},},
	PreviousTrackedChange:{text:{menu:_('Pr~evious'),},},
	Print:{global:{menu:_('~Print...'),},},
	RecalcPivotTable:{spreadsheet:{menu:_('~Refresh'),},},
	Redo:{global:{menu:_('~Redo'),},},
	RejectAllTrackedChanges:{text:{menu:_('Reject All'),},},
	Remove:{spreadsheet:{menu:_('~Delete Sheet...'),},},
	RemoveHyperlink:{text:{menu:_('Remove Hyperlink'),},},
	RemoveTableOf:{text:{menu:_('Delete index'),},},
	RenameTable:{spreadsheet:{menu:_('~Rename Sheet...'),},},
	ReplyComment:{global:{menu:_('Reply Comment'),},},
	ResetAttributes:{global:{menu:_('~Clear Direct Formatting'),},spreadsheet:{menu:_('Clear ~Direct Formatting'),},text:{menu:_('Clear ~Direct Formatting'),},},
	RightPara:{global:{context:_('Align Right'),menu:_('Right'),},},
	RotateLeft:{text:{menu:_('Rotate 90° ~Left'),},},
	RotateMenu:{global:{menu:_('Rot~ate'),},},
	RotateRight:{text:{menu:_('Rotate 90° ~Right'),},},
	Save:{global:{menu:_('~Save'),},},
	SaveAs:{global:{menu:_('Save ~As...'),},},
	SearchDialog:{global:{menu:_('Find & Rep~lace...'),},},
	SelectAll:{global:{menu:_('Select ~All'),},},
	SelectTable:{presentation:{menu:_('~Select...'),},text:{menu:_('~Table'),},},
	SendToBack:{global:{menu:_('~Send to Back'),},},
	SetAnchorAtChar:{text:{menu:_('To ~Character'),},},
	SetAnchorToChar:{text:{menu:_('As C~haracter'),},},
	SetAnchorToFrame:{text:{menu:_('To ~Frame'),},},
	SetAnchorToPage:{spreadsheet:{menu:_('To P~age'),},text:{menu:_('To P~age'),},},
	SetAnchorToPara:{text:{menu:_('To ~Paragraph'),},},
	SetDocumentProperties:{global:{menu:_('Propert~ies...'),},},
	SetLanguageAllTextMenu:{global:{menu:_('For All Text'),},},
	SetLanguageParagraphMenu:{global:{menu:_('For Paragraph'),},},
	SetLanguageSelectionMenu:{global:{menu:_('For Selection'),},},
	SetOptimalColumnWidth:{presentation:{menu:_('Optimal Column Width'),},spreadsheet:{menu:_('~Optimal Width...'),},text:{menu:_('Optimal Column Width'),},},
	SetOptimalRowHeight:{presentation:{menu:_('Optimal Row Height'),},spreadsheet:{menu:_('~Optimal Height...'),},text:{menu:_('Optimal Row Height'),},},
	Shadowed:{global:{menu:_('Shadow'),},},
	SheetMenu:{spreadsheet:{menu:_('~Sheet'),},},
	Show:{spreadsheet:{menu:_('~Show Sheet...'),},},
	ShowColumn:{spreadsheet:{context:_('S~how Columns'),menu:_('~Show'),},},
	ShowDetail:{global:{menu:_('~Show Details'),},},
	ShowRow:{spreadsheet:{context:_('Sho~w Rows'),menu:_('~Show'),},},
	ShowTrackedChanges:{text:{menu:_('~Show'),},},
	Shrink:{global:{menu:_('Decrease Size'),},},
	SlideMenu:{presentation:{menu:_('S~lide'),},},
	SmallCaps:{global:{menu:_('Small capitals'),},},
	SortAscending:{spreadsheet:{menu:_('Sort Ascending'),},},
	SortDescending:{spreadsheet:{menu:_('Sort Descending'),},},
	SpacePara1:{global:{menu:_('Line Spacing: 1'),},},
	SpacePara15:{global:{menu:_('Line Spacing: 1.5'),},},
	SpacePara2:{global:{menu:_('Line Spacing: 2'),},},
	SpellOnline:{global:{menu:_('~Automatic Spell Checking'),},},
	SpellingAndGrammarDialog:{global:{menu:_('~Spelling...'),},},
	SplitCell:{presentation:{menu:_('Split Cells'),},spreadsheet:{menu:_('Split Cells'),},text:{menu:_('Split Cells...'),},},
	Strikeout:{global:{menu:_('Strikethrough'),},},
	SubScript:{global:{menu:_('Subscript'),},text:{menu:_('Subscript'),},},
	SuperScript:{global:{menu:_('Superscript'),},text:{menu:_('Superscript'),},},
	TableDeleteMenu:{global:{menu:_('~Delete'),},},
	TableDialog:{presentation:{menu:_('~Properties...'),},text:{menu:_('~Properties...'),},},
	TableInsertMenu:{global:{menu:_('~Insert'),},},
	TableMenu:{global:{menu:_('T~able'),},},
	TableSelectMenu:{text:{menu:_('~Select'),},},
	TaskPaneInsertPage:{presentation:{menu:_('Insert Slide'),},},
	TextAlign:{global:{menu:_('Alig~n'),},},
	ThesaurusDialog:{global:{menu:_('~Thesaurus...'),},text:{menu:_('~Thesaurus...'),},},
	ToggleMergeCells:{spreadsheet:{menu:_('M~erge and Center Cells'),},},
	ToolsMenu:{global:{menu:_('~Tools'),},},
	TrackChanges:{text:{menu:_('~Record'),},},
	TransformDialog:{global:{menu:_('Position and Si~ze...'),},},
	Underline:{global:{menu:_('Underline'),},},
	UnderlineDouble:{global:{menu:_('Double Underline'),},},
	Undo:{global:{menu:_('~Undo'),},},
	Ungroup:{global:{menu:_('~Ungroup...'),},},
	UpSearch:{global:{menu:_('Find Previous'),},},
	UpdateCurIndex:{text:{context:_('Update index'),menu:_('Current ~Index'),},},
	Validation:{spreadsheet:{menu:_('~Validity...'),},},
	ViewMenu:{global:{menu:_('~View'),},},
	WordCountDialog:{text:{menu:_('~Word Count...'),},},
	WrapAnchorOnly:{text:{menu:_('~First Paragraph'),},},
	WrapContour:{text:{menu:_('~Contour'),},},
	WrapIdeal:{text:{menu:_('~Optimal Page Wrap'),},},
	WrapLeft:{text:{menu:_('Wrap Left'),},},
	WrapMenu:{text:{menu:_('~Wrap'),},},
	WrapOff:{text:{menu:_('Wrap Off'),},},
	WrapOn:{text:{menu:_('~Page Wrap'),},},
	WrapRight:{text:{menu:_('Wrap Right'),},},
	WrapText:{spreadsheet:{menu:_('Wrap Text'),},},
	WrapThrough:{text:{menu:_('~Wrap Through'),},},
	WrapThroughTransparent:{text:{menu:_('In ~Background'),},},
	ZoomMinus:{global:{menu:_('Zoom Out'),},},
	ZoomPlus:{global:{menu:_('Zoom In'),},},
};

window._UNO = function(string, component, isContext) {
	var command = string.substr(5);
	var context = 'menu';
	if (isContext === true) {
		context = 'context';
	}
	var entry = unoCommandsArray[command];
	if (entry === undefined) {
		return command;
	}
	var componentEntry = entry[component];
	if (componentEntry === undefined) {
		componentEntry = entry['global'];
		if (componentEntry === undefined) {
			return command;
		}
	}
	var text = componentEntry[context];
	if (text === undefined) {
		text = componentEntry['menu'];
		if (text === undefined) {
			return command;
		}
	}

	// Remove access key markers from translated strings
	// 1. access key in parenthesis in case of non-latin scripts
	text = text.replace(/\(~[A-Za-z]\)/, '');
	// 2. remove normal access key
	text = text.replace('~', '');

	return text;
}
